# Resources

## I3 official

* [i3wm](https://i3wm.org/)
* [i3wm reddit group (FAQs)](https://www.reddit.com/r/i3wm/)
* [Archlinux Wiki](https://wiki.archlinux.org/index.php/I3)

## Other Tools

... from the i3wm ecosystem

* [online color configurator](https://thomashunter.name/i3-configurator/)
* [j4-make-config (i3-theme)](https://github.com/okraits/j4-make-config)
* [i3-style](https://github.com/acrisci/i3-style)
* [i3ColourChanger](https://github.com/PMunch/i3ColourChanger)
* [i3-manager](https://github.com/erayaydin/i3-manager)
